@@ -83,22 +83,28 @@ void moserial_main_run (moserialMain* self) {
 gint moserial_main_main (char** args, int args_length1) {
 	GError * inner_error;
 	GOptionContext* context;
-	gint _tmp1;
+	GOptionContext* _tmp0;
+	gint _tmp2;
 	inner_error = NULL;
+	context = NULL;
 	gtk_init (&args_length1, &args);
-	context = g_option_context_new (_ ("- moserial serial terminal"));
+	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+	_tmp0 = NULL;
+	context = (_tmp0 = g_option_context_new (_ ("- moserial serial terminal")), (context == NULL) ? NULL : (context = (g_option_context_free (context), NULL)), _tmp0);
 	g_option_context_add_main_entries (context, MOSERIAL_MAIN_options, NULL);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	{
-		gboolean _tmp0;
-		_tmp0 = g_option_context_parse (context, &args_length1, &args, &inner_error);
+		gboolean _tmp1;
+		_tmp1 = g_option_context_parse (context, &args_length1, &args, &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_OPTION_ERROR) {
 				goto __catch5_g_option_error;
 			}
 			goto __finally5;
 		}
-		if (!_tmp0) {
+		if (!_tmp1) {
 			fprintf (stdout, _ ("Run '%s --help' to see a full list of available command line options.\n"), args[0]);
 		} else {
 			moserialMain* app;
@@ -127,7 +133,7 @@ gint moserial_main_main (char** args, int args_length1) {
 		g_clear_error (&inner_error);
 		return 0;
 	}
-	return (_tmp1 = 0, (context == NULL) ? NULL : (context = (g_option_context_free (context), NULL)), _tmp1);
+	return (_tmp2 = 0, (context == NULL) ? NULL : (context = (g_option_context_free (context), NULL)), _tmp2);
 }
 
 
