@@ -88,7 +88,7 @@ void moserial_preferences_dialog_ok (moserialPreferencesDialog* self, GtkButton*
 	Preferences* preferences;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (button != NULL);
-	moserial_preferences_dialog_hide (self, (GtkWidget*) button);
+	moserial_preferences_dialog_hide (self);
 	pSystemFont = FALSE;
 	pFont = NULL;
 	pFontColor = NULL;
@@ -182,13 +182,12 @@ void moserial_preferences_dialog_cancel (moserialPreferencesDialog* self, GtkWid
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (w != NULL);
 	/*currentPreferences=null;*/
-	moserial_preferences_dialog_hide (self, w);
+	moserial_preferences_dialog_hide (self);
 }
 
 
-gboolean moserial_preferences_dialog_hide (moserialPreferencesDialog* self, GtkWidget* w) {
+gboolean moserial_preferences_dialog_hide (moserialPreferencesDialog* self) {
 	g_return_val_if_fail (self != NULL, FALSE);
-	g_return_val_if_fail (w != NULL, FALSE);
 	gtk_widget_hide_all ((GtkWidget*) self->priv->dialog);
 	return TRUE;
 }
@@ -254,7 +253,7 @@ static void _moserial_preferences_dialog_cancel_gtk_button_clicked (GtkButton* _
 
 
 static gboolean _moserial_preferences_dialog_hide_gtk_widget_delete_event (GtkDialog* _sender, const GdkEvent* event, gpointer self) {
-	return moserial_preferences_dialog_hide (self, _sender);
+	return moserial_preferences_dialog_hide (self);
 }
 
 
