@@ -23,6 +23,7 @@ struct _moserialSettingsDialogPrivate {
 	GtkCheckButton* softwareHandshake;
 	GtkComboBox* accessModeCombo;
 	GtkCheckButton* localEcho;
+	GtkListStore* ls;
 };
 
 #define MOSERIAL_SETTINGS_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), MOSERIAL_TYPE_SETTINGS_DIALOG, moserialSettingsDialogPrivate))
@@ -31,6 +32,7 @@ enum  {
 	MOSERIAL_SETTINGS_DIALOG_BUILDER
 };
 #define MOSERIAL_SETTINGS_DIALOG_max_devices 32
+static void _g_list_free_g_free (GList* self);
 static void moserial_settings_dialog_populateDevices (moserialSettingsDialog* self);
 static void moserial_settings_dialog_set_builder (moserialSettingsDialog* self, GtkBuilder* value);
 static gboolean _moserial_settings_dialog_hide_gtk_widget_delete_event (GtkDialog* _sender, const GdkEvent* event, gpointer self);
@@ -69,40 +71,49 @@ moserialSettingsDialog* moserial_settings_dialog_new (GtkBuilder* builder) {
 }
 
 
+static void _g_list_free_g_free (GList* self) {
+	g_list_foreach (self, (GFunc) g_free, NULL);
+	g_list_free (self);
+}
+
+
 static void moserial_settings_dialog_populateDevices (moserialSettingsDialog* self) {
-	GtkListStore* ls;
+	GList* deviceTypes;
 	GtkTreeIter iter = {0};
 	g_return_if_fail (self != NULL);
-	ls = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING, NULL);
-	gtk_combo_box_set_model ((GtkComboBox*) self->priv->deviceCombo, (GtkTreeModel*) ls);
-	gtk_combo_box_entry_set_text_column (self->priv->deviceCombo, 1);
+	deviceTypes = NULL;
+	deviceTypes = g_list_append (deviceTypes, g_strdup ("/dev/ttyS"));
+	deviceTypes = g_list_append (deviceTypes, g_strdup ("/dev/ttyUSB"));
+	deviceTypes = g_list_append (deviceTypes, g_strdup ("/dev/rfcomm"));
+	gtk_list_store_clear (self->priv->ls);
 	{
-		gint i;
-		i = 0;
-		for (; i < MOSERIAL_SETTINGS_DIALOG_max_devices; i++) {
-			char* dev;
-			dev = g_strdup_printf ("/dev/ttyS%d", i);
-			if (g_file_test (dev, G_FILE_TEST_EXISTS)) {
-				gtk_list_store_append (ls, &iter);
-				gtk_list_store_set (ls, &iter, 0, "", 1, dev, -1, -1);
+		GList* devType_collection;
+		GList* devType_it;
+		devType_collection = deviceTypes;
+		for (devType_it = devType_collection; devType_it != NULL; devType_it = devType_it->next) {
+			const char* _tmp0;
+			char* devType;
+			_tmp0 = NULL;
+			devType = (_tmp0 = (const char*) devType_it->data, (_tmp0 == NULL) ? NULL : g_strdup (_tmp0));
+			{
+				{
+					gint i;
+					i = 0;
+					for (; i < MOSERIAL_SETTINGS_DIALOG_max_devices; i++) {
+						char* dev;
+						dev = g_strdup_printf ("%s%d", devType, i);
+						if (g_file_test (dev, G_FILE_TEST_EXISTS)) {
+							gtk_list_store_append (self->priv->ls, &iter);
+							gtk_list_store_set (self->priv->ls, &iter, 0, "", 1, dev, -1, -1);
+						}
+						dev = (g_free (dev), NULL);
+					}
+				}
+				devType = (g_free (devType), NULL);
 			}
-			dev = (g_free (dev), NULL);
 		}
 	}
-	{
-		gint i;
-		i = 0;
-		for (; i < MOSERIAL_SETTINGS_DIALOG_max_devices; i++) {
-			char* dev;
-			dev = g_strdup_printf ("/dev/ttyUSB%d", i);
-			if (g_file_test (dev, G_FILE_TEST_EXISTS)) {
-				gtk_list_store_append (ls, &iter);
-				gtk_list_store_set (ls, &iter, 0, "", 1, dev, -1, -1);
-			}
-			dev = (g_free (dev), NULL);
-		}
-	}
-	(ls == NULL) ? NULL : (ls = (g_object_unref (ls), NULL));
+	(deviceTypes == NULL) ? NULL : (deviceTypes = (_g_list_free_g_free (deviceTypes), NULL));
 }
 
 
@@ -111,6 +122,7 @@ void moserial_settings_dialog_show (moserialSettingsDialog* self, Settings* sett
 	Settings* _tmp0;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (settings != NULL);
+	moserial_settings_dialog_populateDevices (self);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->currentSettings = (_tmp1 = (_tmp0 = settings, (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->priv->currentSettings == NULL) ? NULL : (self->priv->currentSettings = (g_object_unref (self->priv->currentSettings), NULL)), _tmp1);
@@ -245,7 +257,7 @@ void moserial_settings_dialog_loadSettings (moserialSettingsDialog* self) {
 }
 
 
-gboolean moserial_settings_dialog_hide (moserialSettingsDialog* self, GtkWidget* w) {
+gboolean moserial_settings_dialog_hide (moserialSettingsDialog* self, GtkWidget* w, const GdkEvent* event) {
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (w != NULL, FALSE);
 	gtk_widget_hide_all ((GtkWidget*) self->priv->dialog);
@@ -259,7 +271,7 @@ void moserial_settings_dialog_cancel (moserialSettingsDialog* self, GtkWidget* w
 	g_return_if_fail (w != NULL);
 	_tmp0 = NULL;
 	self->priv->currentSettings = (_tmp0 = NULL, (self->priv->currentSettings == NULL) ? NULL : (self->priv->currentSettings = (g_object_unref (self->priv->currentSettings), NULL)), _tmp0);
-	moserial_settings_dialog_hide (self, w);
+	gtk_widget_hide_all ((GtkWidget*) self->priv->dialog);
 }
 
 
@@ -323,7 +335,7 @@ void moserial_settings_dialog_ok (moserialSettingsDialog* self, GtkWidget* w) {
 	_tmp4 = NULL;
 	self->priv->currentSettings = (_tmp5 = (_tmp4 = self->priv->settings, (_tmp4 == NULL) ? NULL : g_object_ref (_tmp4)), (self->priv->currentSettings == NULL) ? NULL : (self->priv->currentSettings = (g_object_unref (self->priv->currentSettings), NULL)), _tmp5);
 	g_signal_emit_by_name (self, "update-settings", self->priv->currentSettings);
-	moserial_settings_dialog_hide (self, w);
+	gtk_widget_hide_all ((GtkWidget*) self->priv->dialog);
 	device = (g_free (device), NULL);
 }
 
@@ -346,7 +358,7 @@ static void moserial_settings_dialog_set_builder (moserialSettingsDialog* self,
 
 
 static gboolean _moserial_settings_dialog_hide_gtk_widget_delete_event (GtkDialog* _sender, const GdkEvent* event, gpointer self) {
-	return moserial_settings_dialog_hide (self, _sender);
+	return moserial_settings_dialog_hide (self, _sender, event);
 }
 
 
@@ -376,24 +388,25 @@ static GObject * moserial_settings_dialog_constructor (GType type, guint n_const
 		GtkButton* _tmp2;
 		GtkButton* _tmp5;
 		GtkButton* _tmp4;
-		GtkComboBoxEntry* _tmp7;
-		GtkComboBoxEntry* _tmp6;
+		GtkComboBox* _tmp7;
+		GtkComboBox* _tmp6;
 		GtkComboBox* _tmp9;
 		GtkComboBox* _tmp8;
 		GtkComboBox* _tmp11;
 		GtkComboBox* _tmp10;
 		GtkComboBox* _tmp13;
 		GtkComboBox* _tmp12;
-		GtkComboBox* _tmp15;
-		GtkComboBox* _tmp14;
+		GtkCheckButton* _tmp15;
+		GtkCheckButton* _tmp14;
 		GtkCheckButton* _tmp17;
 		GtkCheckButton* _tmp16;
-		GtkCheckButton* _tmp19;
-		GtkCheckButton* _tmp18;
-		GtkComboBox* _tmp21;
-		GtkComboBox* _tmp20;
-		GtkCheckButton* _tmp23;
-		GtkCheckButton* _tmp22;
+		GtkComboBox* _tmp19;
+		GtkComboBox* _tmp18;
+		GtkCheckButton* _tmp21;
+		GtkCheckButton* _tmp20;
+		GtkListStore* _tmp22;
+		GtkComboBoxEntry* _tmp24;
+		GtkComboBoxEntry* _tmp23;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
 		self->priv->dialog = (_tmp1 = (_tmp0 = GTK_DIALOG (gtk_builder_get_object (self->priv->_builder, "settings_dialog")), (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->priv->dialog == NULL) ? NULL : (self->priv->dialog = (g_object_unref (self->priv->dialog), NULL)), _tmp1);
@@ -405,35 +418,38 @@ static GObject * moserial_settings_dialog_constructor (GType type, guint n_const
 		self->priv->okButton = (_tmp5 = (_tmp4 = GTK_BUTTON (gtk_builder_get_object (self->priv->_builder, "settings_ok_button")), (_tmp4 == NULL) ? NULL : g_object_ref (_tmp4)), (self->priv->okButton == NULL) ? NULL : (self->priv->okButton = (g_object_unref (self->priv->okButton), NULL)), _tmp5);
 		_tmp7 = NULL;
 		_tmp6 = NULL;
-		self->priv->deviceCombo = (_tmp7 = (_tmp6 = GTK_COMBO_BOX_ENTRY (gtk_builder_get_object (self->priv->_builder, "settings_device")), (_tmp6 == NULL) ? NULL : g_object_ref (_tmp6)), (self->priv->deviceCombo == NULL) ? NULL : (self->priv->deviceCombo = (g_object_unref (self->priv->deviceCombo), NULL)), _tmp7);
+		self->priv->baudRateCombo = (_tmp7 = (_tmp6 = GTK_COMBO_BOX (gtk_builder_get_object (self->priv->_builder, "settings_baud_rate")), (_tmp6 == NULL) ? NULL : g_object_ref (_tmp6)), (self->priv->baudRateCombo == NULL) ? NULL : (self->priv->baudRateCombo = (g_object_unref (self->priv->baudRateCombo), NULL)), _tmp7);
 		_tmp9 = NULL;
 		_tmp8 = NULL;
-		self->priv->baudRateCombo = (_tmp9 = (_tmp8 = GTK_COMBO_BOX (gtk_builder_get_object (self->priv->_builder, "settings_baud_rate")), (_tmp8 == NULL) ? NULL : g_object_ref (_tmp8)), (self->priv->baudRateCombo == NULL) ? NULL : (self->priv->baudRateCombo = (g_object_unref (self->priv->baudRateCombo), NULL)), _tmp9);
+		self->priv->dataBitsCombo = (_tmp9 = (_tmp8 = GTK_COMBO_BOX (gtk_builder_get_object (self->priv->_builder, "settings_data_bits")), (_tmp8 == NULL) ? NULL : g_object_ref (_tmp8)), (self->priv->dataBitsCombo == NULL) ? NULL : (self->priv->dataBitsCombo = (g_object_unref (self->priv->dataBitsCombo), NULL)), _tmp9);
 		_tmp11 = NULL;
 		_tmp10 = NULL;
-		self->priv->dataBitsCombo = (_tmp11 = (_tmp10 = GTK_COMBO_BOX (gtk_builder_get_object (self->priv->_builder, "settings_data_bits")), (_tmp10 == NULL) ? NULL : g_object_ref (_tmp10)), (self->priv->dataBitsCombo == NULL) ? NULL : (self->priv->dataBitsCombo = (g_object_unref (self->priv->dataBitsCombo), NULL)), _tmp11);
+		self->priv->stopBitsCombo = (_tmp11 = (_tmp10 = GTK_COMBO_BOX (gtk_builder_get_object (self->priv->_builder, "settings_stop_bits")), (_tmp10 == NULL) ? NULL : g_object_ref (_tmp10)), (self->priv->stopBitsCombo == NULL) ? NULL : (self->priv->stopBitsCombo = (g_object_unref (self->priv->stopBitsCombo), NULL)), _tmp11);
 		_tmp13 = NULL;
 		_tmp12 = NULL;
-		self->priv->stopBitsCombo = (_tmp13 = (_tmp12 = GTK_COMBO_BOX (gtk_builder_get_object (self->priv->_builder, "settings_stop_bits")), (_tmp12 == NULL) ? NULL : g_object_ref (_tmp12)), (self->priv->stopBitsCombo == NULL) ? NULL : (self->priv->stopBitsCombo = (g_object_unref (self->priv->stopBitsCombo), NULL)), _tmp13);
+		self->priv->parityCombo = (_tmp13 = (_tmp12 = GTK_COMBO_BOX (gtk_builder_get_object (self->priv->_builder, "settings_parity")), (_tmp12 == NULL) ? NULL : g_object_ref (_tmp12)), (self->priv->parityCombo == NULL) ? NULL : (self->priv->parityCombo = (g_object_unref (self->priv->parityCombo), NULL)), _tmp13);
 		_tmp15 = NULL;
 		_tmp14 = NULL;
-		self->priv->parityCombo = (_tmp15 = (_tmp14 = GTK_COMBO_BOX (gtk_builder_get_object (self->priv->_builder, "settings_parity")), (_tmp14 == NULL) ? NULL : g_object_ref (_tmp14)), (self->priv->parityCombo == NULL) ? NULL : (self->priv->parityCombo = (g_object_unref (self->priv->parityCombo), NULL)), _tmp15);
+		self->priv->hardwareHandshake = (_tmp15 = (_tmp14 = GTK_CHECK_BUTTON (gtk_builder_get_object (self->priv->_builder, "settings_hardware_handshake")), (_tmp14 == NULL) ? NULL : g_object_ref (_tmp14)), (self->priv->hardwareHandshake == NULL) ? NULL : (self->priv->hardwareHandshake = (g_object_unref (self->priv->hardwareHandshake), NULL)), _tmp15);
 		_tmp17 = NULL;
 		_tmp16 = NULL;
-		self->priv->hardwareHandshake = (_tmp17 = (_tmp16 = GTK_CHECK_BUTTON (gtk_builder_get_object (self->priv->_builder, "settings_hardware_handshake")), (_tmp16 == NULL) ? NULL : g_object_ref (_tmp16)), (self->priv->hardwareHandshake == NULL) ? NULL : (self->priv->hardwareHandshake = (g_object_unref (self->priv->hardwareHandshake), NULL)), _tmp17);
+		self->priv->softwareHandshake = (_tmp17 = (_tmp16 = GTK_CHECK_BUTTON (gtk_builder_get_object (self->priv->_builder, "settings_software_handshake")), (_tmp16 == NULL) ? NULL : g_object_ref (_tmp16)), (self->priv->softwareHandshake == NULL) ? NULL : (self->priv->softwareHandshake = (g_object_unref (self->priv->softwareHandshake), NULL)), _tmp17);
 		_tmp19 = NULL;
 		_tmp18 = NULL;
-		self->priv->softwareHandshake = (_tmp19 = (_tmp18 = GTK_CHECK_BUTTON (gtk_builder_get_object (self->priv->_builder, "settings_software_handshake")), (_tmp18 == NULL) ? NULL : g_object_ref (_tmp18)), (self->priv->softwareHandshake == NULL) ? NULL : (self->priv->softwareHandshake = (g_object_unref (self->priv->softwareHandshake), NULL)), _tmp19);
+		self->priv->accessModeCombo = (_tmp19 = (_tmp18 = GTK_COMBO_BOX (gtk_builder_get_object (self->priv->_builder, "settings_open_for")), (_tmp18 == NULL) ? NULL : g_object_ref (_tmp18)), (self->priv->accessModeCombo == NULL) ? NULL : (self->priv->accessModeCombo = (g_object_unref (self->priv->accessModeCombo), NULL)), _tmp19);
 		_tmp21 = NULL;
 		_tmp20 = NULL;
-		self->priv->accessModeCombo = (_tmp21 = (_tmp20 = GTK_COMBO_BOX (gtk_builder_get_object (self->priv->_builder, "settings_open_for")), (_tmp20 == NULL) ? NULL : g_object_ref (_tmp20)), (self->priv->accessModeCombo == NULL) ? NULL : (self->priv->accessModeCombo = (g_object_unref (self->priv->accessModeCombo), NULL)), _tmp21);
-		_tmp23 = NULL;
-		_tmp22 = NULL;
-		self->priv->localEcho = (_tmp23 = (_tmp22 = GTK_CHECK_BUTTON (gtk_builder_get_object (self->priv->_builder, "settings_local_echo")), (_tmp22 == NULL) ? NULL : g_object_ref (_tmp22)), (self->priv->localEcho == NULL) ? NULL : (self->priv->localEcho = (g_object_unref (self->priv->localEcho), NULL)), _tmp23);
+		self->priv->localEcho = (_tmp21 = (_tmp20 = GTK_CHECK_BUTTON (gtk_builder_get_object (self->priv->_builder, "settings_local_echo")), (_tmp20 == NULL) ? NULL : g_object_ref (_tmp20)), (self->priv->localEcho == NULL) ? NULL : (self->priv->localEcho = (g_object_unref (self->priv->localEcho), NULL)), _tmp21);
 		g_signal_connect_object ((GtkWidget*) self->priv->dialog, "delete-event", (GCallback) _moserial_settings_dialog_hide_gtk_widget_delete_event, self, 0);
 		g_signal_connect_object (self->priv->cancelButton, "clicked", (GCallback) _moserial_settings_dialog_cancel_gtk_button_clicked, self, 0);
 		g_signal_connect_object (self->priv->okButton, "clicked", (GCallback) _moserial_settings_dialog_ok_gtk_button_clicked, self, 0);
-		moserial_settings_dialog_populateDevices (self);
+		_tmp22 = NULL;
+		self->priv->ls = (_tmp22 = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING, NULL), (self->priv->ls == NULL) ? NULL : (self->priv->ls = (g_object_unref (self->priv->ls), NULL)), _tmp22);
+		_tmp24 = NULL;
+		_tmp23 = NULL;
+		self->priv->deviceCombo = (_tmp24 = (_tmp23 = GTK_COMBO_BOX_ENTRY (gtk_builder_get_object (self->priv->_builder, "settings_device")), (_tmp23 == NULL) ? NULL : g_object_ref (_tmp23)), (self->priv->deviceCombo == NULL) ? NULL : (self->priv->deviceCombo = (g_object_unref (self->priv->deviceCombo), NULL)), _tmp24);
+		gtk_combo_box_set_model ((GtkComboBox*) self->priv->deviceCombo, (GtkTreeModel*) self->priv->ls);
+		gtk_combo_box_entry_set_text_column (self->priv->deviceCombo, 1);
 	}
 	return obj;
 }
@@ -503,6 +519,7 @@ static void moserial_settings_dialog_finalize (GObject* obj) {
 	(self->priv->softwareHandshake == NULL) ? NULL : (self->priv->softwareHandshake = (g_object_unref (self->priv->softwareHandshake), NULL));
 	(self->priv->accessModeCombo == NULL) ? NULL : (self->priv->accessModeCombo = (g_object_unref (self->priv->accessModeCombo), NULL));
 	(self->priv->localEcho == NULL) ? NULL : (self->priv->localEcho = (g_object_unref (self->priv->localEcho), NULL));
+	(self->priv->ls == NULL) ? NULL : (self->priv->ls = (g_object_unref (self->priv->ls), NULL));
 	G_OBJECT_CLASS (moserial_settings_dialog_parent_class)->finalize (obj);
 }
 
